# Changelog

<!--next-version-placeholder-->

## v0.1.0 (2022-05-22)
### Feature
* Add setup.py ([`2371676`](https://github.com/Kraymer/pawnstore/commit/23716764c852c9086a9778e4160c078c96662782))
* Initial version with chess.com and lichess importers ([`a04a730`](https://github.com/Kraymer/pawnstore/commit/a04a730badef51da850d5bf8132cee7b200ee274))
* Add .gitignore, pre-commit-config and requirements.txt ([`9327b4f`](https://github.com/Kraymer/pawnstore/commit/9327b4f46b1963b878137fab2a4e6bd8b2f761cd))

### Fix
* Return games of given users only ([`df9f54f`](https://github.com/Kraymer/pawnstore/commit/df9f54fc3ed7a9ea9a8dcb40c3bb0bef66057ec3))
* Chess.com time control setting ([`8c9f8dc`](https://github.com/Kraymer/pawnstore/commit/8c9f8dca2001890d44e80da55f9170277072b527))
* Remove unnecessary calls to lichess api ([`801ad1a`](https://github.com/Kraymer/pawnstore/commit/801ad1a054b32819edfe9a767820538db3eeecf1))
* Make LICHESS_API_TOKEN env var definition optional ([`b14451e`](https://github.com/Kraymer/pawnstore/commit/b14451e347ddc62c432662f54f45c342d244c01d))
* Add missing "full" parameter ([`2805ead`](https://github.com/Kraymer/pawnstore/commit/2805eadd4d575c64a681f4b55c423a196383c8ab))
